<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="en_US">
<context>
    <name>CreateFieldDialog</name>
    <message>
        <location filename="../../DetailedWindow.cpp" line="1142"/>
        <source>Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="1155"/>
        <source>Type</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="1165"/>
        <source>String</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="1166"/>
        <source>Text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="1167"/>
        <source>Date</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="1168"/>
        <source>Number</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="1169"/>
        <source>Phone Number</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="1170"/>
        <source>Password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="1171"/>
        <source>URL</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="1176"/>
        <source>Order</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DetailWindow</name>
    <message>
        <location filename="../../DetailedWindow.cpp" line="82"/>
        <source>Copy of </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="129"/>
        <location filename="../../DetailedWindow.cpp" line="352"/>
        <source>Save</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="131"/>
        <location filename="../../DetailedWindow.cpp" line="798"/>
        <location filename="../../DetailedWindow.cpp" line="811"/>
        <source>Delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="132"/>
        <source>Change Face Pict.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="133"/>
        <source>Mirror Face Pict.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="134"/>
        <source>Change Back Pict.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="135"/>
        <source>Mirror Back Pict.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="136"/>
        <source>Delete Face Pict.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="137"/>
        <source>Delete Back Pict.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="138"/>
        <source>Modify fields</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="146"/>
        <source>New Card</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="147"/>
        <source>Edit Card</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="148"/>
        <source>New Card like this</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="149"/>
        <source>Duplicate Card</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="150"/>
        <source>Export Face Pict.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="151"/>
        <source>Export Back Pict.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="178"/>
        <source>Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="189"/>
        <source>Group Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="207"/>
        <source>Membership Info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="208"/>
        <source>Password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="209"/>
        <source>Credit Card</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="210"/>
        <source>Bank Account</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="211"/>
        <source>Health Numbers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="212"/>
        <source>Passport Info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="213"/>
        <source>Note Card</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="214"/>
        <source>Car Info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="215"/>
        <source>Cellular Phone</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="216"/>
        <source>Serial Number Software</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="217"/>
        <source>Serial Number Hardware</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="218"/>
        <source>Web site</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="219"/>
        <source>ID Card</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="220"/>
        <source>Social Security Number</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="221"/>
        <source>Email Account</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="222"/>
        <source>Driver&apos;s License</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="223"/>
        <source>Others</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="227"/>
        <source>Type</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="533"/>
        <location filename="../../DetailedWindow.cpp" line="579"/>
        <source>Click to see</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="632"/>
        <source>Card description is missing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="642"/>
        <source>Type card is missing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="796"/>
        <location filename="../../DetailedWindow.cpp" line="809"/>
        <source>Edit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="797"/>
        <location filename="../../DetailedWindow.cpp" line="810"/>
        <source>Mirror</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="801"/>
        <source>Export Face</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="814"/>
        <source>Export Back</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="835"/>
        <source>Choose card face image file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="837"/>
        <location filename="../../DetailedWindow.cpp" line="979"/>
        <source>Images (*.png);;</source>
        <translation>Images PNG (*.png)</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="850"/>
        <source>Choose card face image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="852"/>
        <location filename="../../DetailedWindow.cpp" line="995"/>
        <source>Images (*.png *.jpg *.gif *.jpeg);;</source>
        <translation>Images (*.png *.jpg *.gif *.jpeg)</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="977"/>
        <source>Choose card back image file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="993"/>
        <source>Choose card back image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="1052"/>
        <source>Are you sure you want to discard changes?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LoginDialog</name>
    <message>
        <location filename="../../LoginDialog.cpp" line="97"/>
        <source>Ok</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../LoginDialog.cpp" line="105"/>
        <source>Clear</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../LoginDialog.cpp" line="149"/>
        <source>About</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../LoginDialog.cpp" line="157"/>
        <source>Donate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../LoginDialog.cpp" line="165"/>
        <source>Exit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../LoginDialog.cpp" line="221"/>
        <source>About Wallet</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../LoginDialog.cpp" line="221"/>
        <source>&lt;qt&gt;&lt;br&gt;&lt;br&gt;&lt;p&gt;&lt;i&gt;&lt;b&gt;qtWallet&lt;/b&gt;&lt;/i&gt;, v.1.0&lt;/p&gt;&lt;p&gt;Developed by &lt;b&gt;nowheremanmail@gmail.com&lt;/b&gt;&lt;/p&gt;&lt;p&gt;Icons by http://pixelmixer.ru/&lt;/p&gt;&lt;p&gt;if you think that qtWallet is useful for you, please&lt;/p&gt;&lt;a href=&quot;https://www.paypal.com/cgi-bin/webscr?cmd=_donations&amp;business=nowheremanmail@gmail.com&amp;lc=US&amp;item_name=qtWallet&amp;currency_code=EUR&amp;bn=PP%2dDonationsBF%3abtn_donate_SM%2egif%3aNonHosted&quot;&gt;DONATE&lt;/a&gt;&lt;/qt&gt;</source>
        <translation>&lt;qt&gt;&lt;br&gt;&lt;br&gt;&lt;p&gt;&lt;i&gt;&lt;b&gt;Wallet&lt;/b&gt;&lt;/i&gt;, v.1.0&lt;/p&gt;&lt;p&gt;Developed by &lt;b&gt;nowheremanmail@gmail.com&lt;/b&gt;&lt;/p&gt;&lt;p&gt;Icons by http://pixelmixer.ru/&lt;/p&gt;&lt;p&gt;if you think that qtWallet is useful for you, please&lt;/p&gt;&lt;a href=&quot;https://www.paypal.com/cgi-bin/webscr?cmd=_donations&amp;business=nowheremanmail@gmail.com&amp;lc=US&amp;item_name=qtWallet&amp;currency_code=EUR&amp;bn=PP%2dDonationsBF%3abtn_donate_SM%2egif%3aNonHosted&quot;&gt;DONATE&lt;/a&gt;&lt;/qt&gt;</translation>
    </message>
    <message>
        <location filename="../../LoginDialog.cpp" line="243"/>
        <source>Password is required</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../LoginDialog.cpp" line="260"/>
        <source>For verification, please, enter your password again</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../LoginDialog.cpp" line="273"/>
        <source>Invalid password, please enter again</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RenameGroupDialog</name>
    <message>
        <location filename="../../eWallet.cpp" line="49"/>
        <source>Save &amp;&amp; Close</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="62"/>
        <source>Name</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>eWallet</name>
    <message>
        <location filename="../../eWallet.cpp" line="444"/>
        <source>Are you sure you want to remove all your data? You will lost all your data</source>
        <translation>Are you sure you want to remove all your data? You will lose all your data</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="469"/>
        <source>Wrong password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="366"/>
        <location filename="../../eWallet.cpp" line="818"/>
        <source>&lt;All&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="385"/>
        <location filename="../../eWallet.cpp" line="827"/>
        <source>&lt;No Group&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="529"/>
        <source>Organization</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="530"/>
        <location filename="../../eWallet.cpp" line="551"/>
        <location filename="../../eWallet.cpp" line="601"/>
        <source>Phone Number</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="531"/>
        <location filename="../../eWallet.cpp" line="565"/>
        <source>Other Information</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="532"/>
        <location filename="../../eWallet.cpp" line="541"/>
        <location filename="../../eWallet.cpp" line="643"/>
        <source>User Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="533"/>
        <location filename="../../eWallet.cpp" line="542"/>
        <location filename="../../eWallet.cpp" line="569"/>
        <location filename="../../eWallet.cpp" line="600"/>
        <location filename="../../eWallet.cpp" line="629"/>
        <location filename="../../eWallet.cpp" line="640"/>
        <location filename="../../eWallet.cpp" line="644"/>
        <location filename="../../eWallet.cpp" line="653"/>
        <source>Password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="534"/>
        <source>Organization club</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="535"/>
        <location filename="../../eWallet.cpp" line="568"/>
        <location filename="../../eWallet.cpp" line="634"/>
        <source>ID Number</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="536"/>
        <location filename="../../eWallet.cpp" line="543"/>
        <location filename="../../eWallet.cpp" line="608"/>
        <location filename="../../eWallet.cpp" line="627"/>
        <location filename="../../eWallet.cpp" line="652"/>
        <source>URL</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="537"/>
        <location filename="../../eWallet.cpp" line="557"/>
        <location filename="../../eWallet.cpp" line="571"/>
        <location filename="../../eWallet.cpp" line="646"/>
        <location filename="../../eWallet.cpp" line="656"/>
        <source>Card Notes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="540"/>
        <location filename="../../eWallet.cpp" line="645"/>
        <source>System</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="546"/>
        <source>Credit Card Type</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="547"/>
        <source>Card Provider</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="548"/>
        <source>Card Number</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="549"/>
        <location filename="../../eWallet.cpp" line="554"/>
        <location filename="../../eWallet.cpp" line="651"/>
        <source>Expiration Date</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="550"/>
        <source>Name on Card</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="552"/>
        <location filename="../../eWallet.cpp" line="563"/>
        <source>PIN</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="553"/>
        <source>Start Date</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="555"/>
        <source>Detail</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="556"/>
        <source>3-digit CVC#</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="560"/>
        <source>Bank Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="561"/>
        <source>Account Number</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="562"/>
        <source>Telephone</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="564"/>
        <source>SWIFT Code</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="570"/>
        <location filename="../../eWallet.cpp" line="635"/>
        <source>Card Title</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="574"/>
        <source>Passport No</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="575"/>
        <source>Surname</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="576"/>
        <source>Given names</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="577"/>
        <source>Date of birth</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="578"/>
        <source>Date of issue</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="579"/>
        <source>Date of expiration</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="580"/>
        <source>Authority</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="583"/>
        <source>Text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="586"/>
        <location filename="../../eWallet.cpp" line="590"/>
        <source>Model</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="587"/>
        <source>Vehicle Number</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="591"/>
        <source>Brand</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="592"/>
        <source>IMEI#</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="593"/>
        <source>Firmware code</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="594"/>
        <source>Purchased</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="595"/>
        <source>Pin1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="596"/>
        <source>Pin2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="597"/>
        <source>Puk1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="598"/>
        <source>Puk2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="599"/>
        <source>Num SIM</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="602"/>
        <source>Manufacturer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="605"/>
        <location filename="../../eWallet.cpp" line="619"/>
        <source>Product</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="606"/>
        <source>Version</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="607"/>
        <location filename="../../eWallet.cpp" line="620"/>
        <source>Serial #</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="609"/>
        <source>Company</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="610"/>
        <source>Date bought</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="611"/>
        <source>Username</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="612"/>
        <location filename="../../eWallet.cpp" line="628"/>
        <source>Login</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="613"/>
        <source>Authorization key</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="614"/>
        <location filename="../../eWallet.cpp" line="623"/>
        <source>Price paid</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="615"/>
        <source>Support</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="616"/>
        <location filename="../../eWallet.cpp" line="631"/>
        <source>Notes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="621"/>
        <source>Model #</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="622"/>
        <source>Bought from</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="624"/>
        <source>Guarantee period</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="630"/>
        <source>E mail used</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="638"/>
        <source>Social Security Number</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="639"/>
        <source>Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="649"/>
        <source>Driver&apos;s License Number</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="650"/>
        <source>Date Issued</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="907"/>
        <source>About</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="909"/>
        <source>Delete DB</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="911"/>
        <location filename="../../eWallet.cpp" line="922"/>
        <source>Exit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="914"/>
        <source>New</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="916"/>
        <location filename="../../eWallet.cpp" line="1390"/>
        <source>Edit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="917"/>
        <source>Invert Sort</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="918"/>
        <source>Import</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="919"/>
        <source>Export</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="921"/>
        <source>Change Password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="981"/>
        <source>Are you sure you want to remove it?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="1129"/>
        <source>Choose import file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="1131"/>
        <location filename="../../eWallet.cpp" line="1409"/>
        <source>Text files (*.txt);;</source>
        <translation>Text files (*.txt)</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="1379"/>
        <source>Rename</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="1380"/>
        <location filename="../../eWallet.cpp" line="1393"/>
        <source>Delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="1389"/>
        <source>View</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="1391"/>
        <source>New like this</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="1392"/>
        <source>Duplicate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="1407"/>
        <source>Choose export file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="1615"/>
        <source>About Wallet</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="1615"/>
        <source>&lt;qt&gt;&lt;br&gt;&lt;br&gt;&lt;p&gt;&lt;i&gt;&lt;b&gt;qtWallet&lt;/b&gt;&lt;/i&gt;, v.1.0&lt;/p&gt;&lt;p&gt;Developed by &lt;b&gt;nowheremanmail@gmail.com&lt;/b&gt;&lt;/p&gt;&lt;p&gt;Icons by http://pixelmixer.ru/&lt;/p&gt;&lt;p&gt;if you think that qtWallet is useful for you, please&lt;/p&gt;&lt;a href=&quot;https://www.paypal.com/cgi-bin/webscr?cmd=_donations&amp;business=nowheremanmail@gmail.com&amp;lc=US&amp;item_name=qtWallet&amp;currency_code=EUR&amp;bn=PP%2dDonationsBF%3abtn_donate_SM%2egif%3aNonHosted&quot;&gt;DONATE&lt;/a&gt;&lt;/qt&gt;</source>
        <translation type="unfinished">&lt;qt&gt;&lt;br&gt;&lt;br&gt;&lt;p&gt;&lt;i&gt;&lt;b&gt;Wallet&lt;/b&gt;&lt;/i&gt;, v.1.0&lt;/p&gt;&lt;p&gt;Developed by &lt;b&gt;nowheremanmail@gmail.com&lt;/b&gt;&lt;/p&gt;&lt;p&gt;Icons by http://pixelmixer.ru/&lt;/p&gt;&lt;p&gt;if you think that qtWallet is useful for you, please&lt;/p&gt;&lt;a href=&quot;https://www.paypal.com/cgi-bin/webscr?cmd=_donations&amp;business=nowheremanmail@gmail.com&amp;lc=US&amp;item_name=qtWallet&amp;currency_code=EUR&amp;bn=PP%2dDonationsBF%3abtn_donate_SM%2egif%3aNonHosted&quot;&gt;DONATE&lt;/a&gt;&lt;/qt&gt;</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="1654"/>
        <source>Changing password, please wait until application quits</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="1660"/>
        <source>Password changed successfully, application will exit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="1662"/>
        <source>Password CANNOT BE changed, because %1, and application will exit</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
